#
# spec file for package jakarta-activation
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global srcname jaf-api
%global artifact_name jakarta.activation-api
# The automatic requires would be java-headless >= 9, but the
# binaries are java 8 compatible
%define __requires_exclude java-headless
Name:           jakarta-activation
Version:        2.1.3
Release:        1.3
Summary:        Jakarta Activation Specification and Implementation
License:        BSD-3-Clause
URL:            https://github.com/jakartaee/%{srcname}
Source0:        https://github.com/jakartaee/%{srcname}/archive/%{version}/%{srcname}-%{version}.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 9
BuildRequires:  javapackages-local >= 6
Requires:       java-headless >= 1.8
BuildArch:      noarch

%description
Jakarta Activation lets you take advantage of standard services to:
determine the type of an arbitrary piece of data; encapsulate access to
it; discover the operations available on it; and instantiate the
appropriate bean to perform the operation(s).

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{srcname}-%{version}
cp %{SOURCE1} api/build.xml

%build
pushd api
%{ant} package javadoc
popd

%install
# jars
install -d -m 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 api/target/%{artifact_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{artifact_name}.jar

#pom
install -d -m 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} api/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{artifact_name}.pom
%add_maven_depmap %{name}/%{artifact_name}.pom %{name}/%{artifact_name}.jar

# javadoc
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
cp -a api/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}

%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md
%license LICENSE.md NOTICE.md

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.md NOTICE.md

%changelog
* Mon Apr 29 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.1.3
  * Changes:
    + #93 - Use OSGi service loader mediator
    + #94 - Loading of service provider implementations needs to be
    done under doPrivileged
    + #100 - Avoid requiring accessDeclaredMembers permissions
    + fix wrong class file version for package-info
    + add missing javadoc description for MimeTypeEntry getters
    + fixes erroneous assumption about classes being loaded from
    Thread.getContextClassLoader
    + allows reproducible build
- Use the new https://github.com/jakartaee/jaf-api URL
* Mon Apr 29 2024 Fridrich Strba <fstrba@suse.com>
- The binaries are compatible with java 1.8
* Thu Mar  3 2022 Fridrich Strba <fstrba@suse.com>
- Rewrite build system to build with ant
* Wed Dec 15 2021 Fridrich Strba <fstrba@suse.com>
- Initial packaging of the new jakarta-activation 2.1.0
